akhdefo_functions.akhdefo_ts_plot — akhdefo 2023 documentation

# akhdefo_functions.akhdefo_ts_plot

akhdefo_functions.akhdefo_ts_plot(path_to_shapefile='', dem_path='', point_size=1.0, opacity=0.75, cmap='turbo', Set_fig_MinMax=True, MinMaxRange=[-50, 50], color_field='VEL', user_data_points='', path_saveData_points='', save_plot=False, Fig_outputDir='', VEL_Scale='year')

  Inputs:

  This program used for analysis time-series velocity profiles

  user_data_points: provide path to csv. file contains x and y coordinate for points of interest you can generate this file by providing path to path_saveData_points (POI.csv).

  This is useful to save mouse click positions to repeat the plots for different datasets for example if you plot several TS profiles for EW velocity product, you can recreate TS for the same exact position by saving POI.csv with path_saveData_points and then use that as input for the another plot such as NS velocity product via setting user_datapoints=”POI.csv”

  path_to_shapefile: type path to timeseries shapefile in stack_data/TS folder

  dem_path=r”” path to dem raster in geotif fromat

  point_size=1.0 size of the sactter plot points

  opacity=0.75 transparency of the scater overlay

  cmap=”turbo” Matplotlib colormap options

  Set_fig_MinMax=True

  MinMaxRange=[-50,50] Normalize plot colormap range

  color_field=’VEL’ ,”VEL_2D”, ‘VEL_N’, ‘VEL_E’, ‘VELDir_MEA’

  user_data_points=””,

  path_saveData_points=””

  save_plot=False,

  Fig_outputDir=’’

  > VEL_Scale=’year’

  Outputs: Interactive figures